library(raster)
library(wvtool)
library(viridis)

col = viridis(1000)
pixeltoCMConversion = 0.02
resizeFactor = 8
n_rows = 3400/resizeFactor - 2

inputDirectory = 'SET_TO_CORRECT_DIRECTORY_PATH'
outputDirectory = 'SET_TO_CORRECT_DIRECTORY_PATH'
setwd(inputDirectory)
i_exp = 5

for(i_exp in 1:length(dir(rootDirectory))){
  
  photoDirectory = paste(inputDirectory,dir(inputDirectory, pattern = 'ShellRacetrack')[i_exp], sep = '')
  setwd(photoDirectory)
  
  n_photos = length(dir(photoDirectory, pattern = '.JPG'))
  outputMatrix = array(NA, dim = c(n_rows, n_photos))
  
  start = Sys.time()
  # i_photo = 1201
  for(i_photo in 1:n_photos){
    
    if(sum(!is.na(outputMatrix[,i_photo])) == 0){
      
      setwd(photoDirectory)
      photo = raster(dir(photoDirectory, pattern = '.JPG',)[i_photo], band = 2)
      photoCropped = raster::crop(photo, extent(photo, 1250, 1900, 1, 3400))
      
      photoResize = aggregate(photoCropped, fact = resizeFactor) 
      M = as.matrix(photoResize)

      m = tanh(M/100)*max(M)

      edge = wvtool::edge.detect(m, thresh1 = 1, thresh2 = 98)
      # plot(raster(edge))
      clearEdges = which(colSums(edge) == 1)
      disputedEdges = which(colSums(edge) > 1)
      
      pixelHeight = rep(NA, times = dim(edge)[2])
      for(i_col in clearEdges){
        pixelHeight[i_col] = which(edge[,i_col] == 1)
      }
      
      for(i_col in disputedEdges){
        # reference = clearEdges[which.min(abs(clearEdges - i_col))][1]
        rangeSize = 2
        referenceHeight = NaN
        while(is.nan(referenceHeight)){
          range = (i_col - rangeSize):(i_col + rangeSize)
          range = range[range > 0]
          referenceHeight = mean(pixelHeight[range], na.rm = T)
          rangeSize = rangeSize + 1
        }
        
        disputedHeights = which(edge[,i_col] == 1)
        
        pixelHeight[i_col] = disputedHeights[which.min(abs(disputedHeights - referenceHeight))]
      }
      
      # ----------
      # Plotting edge-detection output
      y = (dim(photoCropped)[1] - pixelHeight*resizeFactor) + 690
      x = seq(1,3400, length.out = length(y))
      par(mfrow = c(1,1))
      plot(photoResize, col = col, box = F, axes = F, legend = F)
      points(y ~ x, pch = '.', cex = 3)
      # ----------
      
      pixelHeight = dim(edge)[1] - pixelHeight
      pixelHeight = pixelHeight - mean(pixelHeight, na.rm = T)
      rippleHeight.cm = pixelHeight*resizeFactor*pixeltoCMConversion
      # plot(rippleHeight.cm, pch = '.', cex = 3, ylim = c(-10, 10))
      
      rippleHeight.cm = c(rippleHeight.cm, rep(NA, times = n_rows - length(rippleHeight.cm)))
      outputMatrix[,i_photo] = rippleHeight.cm
      
      print(paste(i_photo,'/',n_photos));print((Sys.time() - start))
    }
  }
  setwd(outputDirectory)
  save(outputMatrix, file = paste(dir(rootDirectory)[i_exp],'_output.rda', sep = ''))
  
  # load(dir(outputDirectory)[i_exp])
  plot(raster(outputMatrix), col = col, zlim = c(-4,4), axes = F, box = F, main = i_exp)
  axis(side = 1, at = seq(0,1,length.out = 6), labels = seq(1, dim(outputMatrix)[2], length.out = 6))
  axis(side = 1, line = 1.5, at = 0.5, labels = 'Time step', tick = F)
}


setwd(outputDirectory)
i_exp = 13
load(dir(outputDirectory, pattern = '.rda')[i_exp])
plot(raster(outputMatrix), col = col, zlim = c(-4,4), axes = F, box = F)
axis(side = 1, at = seq(0,1,length.out = 6), labels = seq(1, dim(outputMatrix)[2], length.out = 6))
axis(side = 1, line = 1.5, at = 0.5, labels = 'Time step', tick = F)

