library(raster)
library(viridis)
col = viridis(1000)#colorRampPalette(c('black','white'))(1000)

inputDirectory = 'SET_TO_CORRECT_DIRECTORY_PATH'
outputDirectory = 'SET_TO_CORRECT_DIRECTORY_PATH'
filteredOutputDirectory = 'SET_TO_CORRECT_DIRECTORY_PATH'

n_experiments = length(dir(inputDirectory, pattern = '.rda'))

i_exp = 1
# for(i_exp in 1:n_experiments){

setwd(inputDirectory)
load(dir(inputDirectory, pattern = '.rda')[i_exp])

resizeFactor = 8
pixelsToCM = 0.02
timestepsToMinutes = 10/60

M = outputMatrix
# if(i_exp == 1){
#   M[182:184,1:650] = NA
# }
plot(raster(M), col = col, zlim = c(-4,4))
# Cleaning attempt # 1 (time)
jumpThreshold = 0.5
for(i in 1:dim(M)[1]){

  y = M[i,]
  nonNAs = which(!is.na(y))
  y[1:nonNAs[1]] = y[nonNAs[1]]
  y[nonNAs[length(nonNAs)]:length(y)] = y[nonNAs[length(nonNAs)]]
  x = 1:dim(M)[2]
  
  rejects = which(abs(diff(y)) > jumpThreshold)
  counter = 1
  while(length(rejects) > 0){
    
    y[rejects] = NA
    y = approx(x = x, y = y, n = length(y))$y
    rejects = which(abs(diff(y)) > jumpThreshold)
  }
  y = approx(x = x, y = y, n = length(y))$y
  M[i,] = y
}

# M = as.matrix(flip(raster(M), direction = 'y'))
plot(raster(M), col = col, zlim = c(-4,4), box = F, axes = F, main = i_exp)
labels = seq(0,2000,300)
axis(side = 1, at = labels/dim(M)[2], labels = labels*timestepsToMinutes)
axis(side = 1, line = 1.5, at = 0.5, labels = 'Run time (minutes)', tick = F)
labels = seq(0, 500, 100)
axis(side = 2, at = labels/dim(M)[1], labels = labels*pixelsToCM*resizeFactor)
axis(side = 2, line = 1.5, at = 0.5, labels = 'Position in channel (cm)', tick = F)

setwd(outputDirectory)
save(M, file = dir(inputDirectory, pattern = '.rda')[i_exp])
# }

n_experiments = length(dir(outputDirectory, pattern = '.rda'))
for(i_exp in 1:n_experiments){
  setwd(outputDirectory)
  load(file = dir(outputDirectory, pattern = '.rda')[i_exp])
  M = M[,1:1600]
  plot(raster(M), col = col, zlim = c(-4,4), box = F, axes = F, main = i_exp)
  labels = seq(0,2000,300)
  axis(side = 1, at = labels/dim(M)[2], labels = labels*timestepsToMinutes)
  axis(side = 1, line = 1.5, at = 0.5, labels = 'Run time (minutes)', tick = F)
  labels = seq(0, 500, 100)
  axis(side = 2, at = labels/dim(M)[1], labels = labels*pixelsToCM*resizeFactor)
  axis(side = 2, line = 1.5, at = 0.5, labels = 'Position in channel (cm)', tick = F)
  lines(x = c(0.375,0.375), y = c(0,1))
}



plot(y ~ x, type = 'l', ylim = c(-10,10))

plot(raster(M), col = col, zlim = c(-4,4), box = F, axes = F, main = i_exp)
labels = seq(0,2000,300)
axis(side = 1, at = labels/dim(M)[2], labels = labels*timestepsToMinutes)
axis(side = 1, line = 1.5, at = 0.5, labels = 'Run time (minutes)', tick = F)
labels = seq(0, 500, 100)
axis(side = 2, at = labels/dim(M)[1], labels = labels*pixelsToCM*resizeFactor)
axis(side = 2, line = 1.5, at = 0.5, labels = 'Position in channel (cm)', tick = F)


# ------------- Filter (butterworth) through space
library(signal)
n_experiments = length(dir(outputDirectory, pattern = '.rda'))
for(i_exp in 1:n_experiments){
  # i_exp = 1
  setwd(outputDirectory)
  load(file = dir(outputDirectory, pattern = '.rda')[i_exp])

  M2 = array(NA, dim = dim(M))
  for(i_col in 1:dim(M2)[2]){
    #i_col = runif(n = 1, min = 1, max = dim(M)[2])
    y = M[,i_col]
    x = 1:length(y)  
    
    # # Apply butterworth filter
    bf = butter(2, 1/20, type="low")
    b1 = as.numeric(filter(bf, y))
    
    M2[,i_col] = b1
  }
  par(mfrow = c(1,2))
  M = M[1:(dim(M2)[1] - 10),]
  plot(raster(M), col = col, zlim = c(-4,4), box = F, axes = F, main = i_exp)
  labels = seq(0,2000,300)
  axis(side = 1, at = labels/dim(M)[2], labels = labels*timestepsToMinutes)
  axis(side = 1, line = 1.5, at = 0.5, labels = 'Run time (minutes)', tick = F)
  labels = seq(0, 500, 100)
  axis(side = 2, at = labels/dim(M)[1], labels = labels*pixelsToCM*resizeFactor)
  axis(side = 2, line = 1.5, at = 0.5, labels = 'Position in channel (cm)', tick = F)
  
  M2 = M2[11:dim(M2)[1],]
  plot(raster(M2), col = col, zlim = c(-4,4), box = F, axes = F, main = i_exp)
  labels = seq(0,2000,300)
  axis(side = 1, at = labels/dim(M)[2], labels = labels*timestepsToMinutes)
  axis(side = 1, line = 1.5, at = 0.5, labels = 'Run time (minutes)', tick = F)
  labels = seq(0, 500, 100)
  axis(side = 2, at = labels/dim(M)[1], labels = labels*pixelsToCM*resizeFactor)
  axis(side = 2, line = 1.5, at = 0.5, labels = 'Position in channel (cm)', tick = F)
  par(mfrow = c(1,1))
  
  setwd(filteredOutputDirectory)
  M = M2
  save(M, file = dir(outputDirectory, pattern = '.rda')[i_exp])
}




# # ---------------------------
# Section 2: Calculate ripple parameters 
# # ---------------------------
DD = data.frame(NA,NA,NA,NA,NA, NA)[-1,]
names(DD) = c('rippleLength.pixels', 'rippleHeight.pixels', 'rippleArea.pixels2', 'asymmetry.prop','photoNumber', 'experiment')

library(pracma)
for(i_exp in 1:n_experiments){

setwd(filteredOutputDirectory)
load(file = dir(filteredOutputDirectory, pattern = '.rda')[i_exp])

plot(raster(M), col = col, zlim = c(-4,4), box = F, axes = F, main = i_exp)
labels = seq(0,2000,300)
axis(side = 1, at = labels/dim(M)[2], labels = labels*timestepsToMinutes)
axis(side = 1, line = 1.5, at = 0.5, labels = 'Run time (minutes)', tick = F)
labels = seq(0, 500, 100)
axis(side = 2, at = labels/dim(M)[1], labels = labels*pixelsToCM*resizeFactor)
axis(side = 2, line = 1.5, at = 0.5, labels = 'Position in channel (cm)', tick = F)

plot = F

n_cols = dim(M)[2]
D = data.frame(NA,NA,NA,NA,NA)[-1,]
names(D) = c('rippleLength.pixels', 'rippleHeight.pixels', 'rippleArea.pixels2', 'asymmetry.prop','photoNumber')
for(i_col in 1:n_cols){
  
  # i_col = runif(n = 1, min = 1, max = n_cols)
  y = M[,i_col]
  x = 1:length(y)  
  
  # Find peaks
  findPeaks = findpeaks(y)
  maxs = findPeaks[,2]
  mins = findPeaks[,4]
  maxs = maxs[maxs != length(y)]
  mins = mins[mins != length(y)]
  
  if(plot == T){
    ## --- Plot peaks ---
    plot(y ~ x, type = 'l', ylim = c(-10,10), xlab = 'Photo length (pixels)', ylab = 'Surface height (pixels)')
    points(y[maxs] ~ x[maxs])
    points(y[mins] ~ x[mins])
    ## ------------------
  }
  
  rippleRange = maxs > min(mins) & maxs < max(mins)
  
  n_ripples = length(mins) - 1
  rippleLength.pixels = rep(NA, times = n_ripples)
  rippleHeight.pixels = rep(NA, times = n_ripples)
  rippleArea.pixels2 = rep(NA, times = n_ripples)
  asymmetry.prop = rep(NA, times = n_ripples)
  photoNumber = rep(NA, times = n_ripples)
  for(i_ripple in 1:n_ripples){
    trough1 = mins[i_ripple]
    peak = maxs[rippleRange][i_ripple]
    trough2 = mins[i_ripple + 1]
    
    rippleLength.pixels[i_ripple] = trough2 - trough1
    asymmetry.prop[i_ripple] = abs((peak - trough1) - (trough2 - peak))/(trough2 - trough1)
    rippleHeight.pixels[i_ripple] = y[peak] - mean(c(y[trough1], y[trough2]))
    photoNumber[i_ripple] = i_col
    
    # Ripple area
    rippleBase = approx(x = c(trough1, trough2), y = y[c(trough1, trough2)], n = 1 + (trough2 - trough1))$y
    rippleTop = y[trough1:trough2]
    rippleTop[rippleTop < rippleBase] = rippleBase[rippleTop < rippleBase]
    rippleArea.pixels2[i_ripple] = sum((rippleTop - rippleBase))
    
    if(plot == T){
      ## --- Plot ripple area ---
      lines(rippleTop ~ x[trough1:trough2], type = 'l', ylim = c(-10,10), xlim = c(0, dim(M)[1]), col = 2)
      points(y[c(trough1, peak, trough2)] ~ x[c(trough1, peak, trough2)], col = 2)
      lines(rippleBase ~ x[trough1:trough2], type = 'l', col = 2, lty = 2)
      ## --- Plot ripple area ---
    }
    
  }
  d = data.frame(rippleLength.pixels, rippleHeight.pixels, rippleArea.pixels2, asymmetry.prop, photoNumber)
  D = rbind(D, d)
  print(paste(i_col, '/', n_cols))
}

# Save to file (global dataframe for all experiments)
experimentName = rep(dir(filteredOutputDirectory, pattern = '.rda'))[i_exp]
experimentName = unlist(strsplit(experimentName, split = '_output.rda'))
D = cbind(D, rep(experimentName, times = dim(D)[1]))
names(D) = c('rippleLength.pixels', 'rippleHeight.pixels', 'rippleArea.pixels2', 'asymmetry.prop','photoNumber', 'experiment')
DD = rbind(DD, D)
}
d = DD
# write.csv(d, file = 'rippleParametersConstantFlow.csv')
# write.csv(d, file = 'rippleParametersTidalFlow.csv')

# # ---------------------------
# Section 3: Ripple parameters figures (Constant flow)
# # ---------------------------

setwd('SET_TO_CORRECT_DIRECTORY_PATH')
d = read.csv('rippleMigrationRateConstantFlow_2.csv')
d$experiment[d$experiment == "ShellRacetrack_constantflow_shell_15.0%_1"] = "ShellRacetrack_constantflow_shell_15.0%_2"
d$experiment = factor(d$experiment)

n_experiments = length(levels(d$experiment))
library(scales)
col = viridis(n = n_experiments)

resizeFactor = 8
pixelsToCM = 0.02
timestepsToMinutes = 10/60

d$rippleArea_t0.cm2 = d$rippleArea_t0.pixels2*(pixelsToCM)^2
d$rippleHeight_t0.cm = d$rippleHeight_t0.pixels*(pixelsToCM)
d$rippleLength_t0.cm = d$rippleLength_t0.pixels*(pixelsToCM)
d$time.minutes = d$photoNumber*timestepsToMinutes

# Plot 1 - Regression

m = lm(log(d$rippleArea_t0.cm2) ~ log(d$rippleHeight_t0.cm))
summary(m)
a = m$coefficients[1]
b = m$coefficients[2]
xv = seq(min(d$rippleHeight_t0.cm), max(d$rippleHeight_t0.cm), length.out = 1000)
yv = exp(a + b*log(xv))
plot(yv ~ xv, lty = 1, lwd = 3, col = 'grey', log = 'yx', type = 'l',
     #ylim = c(0.00001,1000), xlim = c(0.00005, 10),
     ylab = 'Ripple area (cm^2)', xlab = 'Ripple height (cm)', xaxt = 'n', yaxt = 'n')
points(d$rippleArea_t0.cm2 ~ d$rippleHeight_t0.cm, pch = '.', col = alpha(col[d$experiment],0.1), cex = 2)
axis(side = 1, at = 10^seq(-10,10, 1), label = 10^seq(-10,10, 1))
axis(side = 2, at = 10^seq(-10,10, 1), label = 10^seq(-10,10, 1))

# Plot 2 - Histograms

shellContentLabel = rep(NA, times = n_experiments)
for(i in 1:n_experiments){
  shellContentLabel[i] = as.numeric(unlist(strsplit(strsplit(levels(d$experiment), split = '_')[[i]][4], split = '%')))
}

index = 1:n_experiments
yv = d$rippleArea_t0.cm2
yv[] = NA
xv = d$experiment
plot(yv ~ xv, log = 'x', ylim = c(min(d$rippleArea_t0.cm2),max(d$rippleArea_t0.cm2)), horizontal = T,
     yaxt = 'n', xaxt = 'n', 
     xlab = 'Sediment shell content (%)', ylab = expression('Ripple area (cm'^2*')'))
axis(side = 1, at = 10^seq(-10,10,1), labels = 10^seq(-10,10,1))
axis(side = 2, at = 1:n_experiments, labels = shellContentLabel, tick = F)
for(i in 1:n_experiments){

  filter = d$experiment == levels(d$experiment)[i] & d$photoNumber > 300
  breaks = seq(-20,0,0.04)
  y = hist(log(d$rippleArea_t0.cm2)[filter], breaks = breaks, plot = F)$density
  x = hist(log(d$rippleArea_t0.cm2)[filter], breaks = breaks, plot = F)$mids
  
  rect(ytop = y + index[i] - 0.4, ybottom = index[i] - 0.4, xright = exp(x - diff(breaks)/2), xleft = exp(x + diff(breaks)/2), col = alpha(col[index[i]], 0.7), lty = 0)
  
  mean = exp(mean(log(d$rippleArea_t0.cm2[filter])))
  mean = mean(d$rippleArea_t0.cm2[filter])
  lines(y = c(index[i]+0.05 - 0.4,index[i] + 0.8 - 0.4), x = c(mean,mean), col = alpha(col[index[i]], 0.7), lwd = 3)
}

# # ---------------------------
# Section 4: Calculate ripple migration
# # ---------------------------

library(pracma)
col = viridis(1000)
interval = 24

D = data.frame(NA,NA,NA,NA)[-1,]
names(D) = c('migration.pixels_photo', 'peakLabel', 'photoNumber', 'experiment')

for(i_exp in 1:n_experiments){
  setwd(filteredOutputDirectory)
  load(file = dir(filteredOutputDirectory, pattern = '.rda')[i_exp])
  
  # plot(raster(M), col = col, zlim = c(-4,4), box = F, axes = F, main = i_exp)
  # labels = seq(0,2000,300)
  # axis(side = 1, at = labels/dim(M)[2], labels = labels*timestepsToMinutes)
  # axis(side = 1, line = 1.5, at = 0.5, labels = 'Run time (minutes)', tick = F)
  # labels = seq(0, 500, 100)
  # axis(side = 2, at = labels/dim(M)[1], labels = labels*pixelsToCM*resizeFactor)
  # axis(side = 2, line = 1.5, at = 0.5, labels = 'Position in channel (cm)', tick = F)

  n_cols = dim(M)[2]
  migration.pixels_photo = c()
  peakLabel = c()
  photoNumber = c()
  for(i_t0 in 1:(n_cols - interval - 1)){
  
    # --------------------
    i_t0 = runif(n = 1, min = 1, max = n_cols - interval)
    y0 = M[,i_t0]
    x0 = 1:length(y0)  
    
    # Find peaks t0
    findPeaks = findpeaks(y0)
    maxs_t0 = findPeaks[,2]
    mins_t0 = findPeaks[,4]
    maxs_t0 = maxs_t0[maxs_t0 != length(y0)]
    mins_t0 = mins_t0[mins_t0 != length(y0)]
    
    plot(y0 ~ x0, type = 'l', ylim = c(-10,10), xlab = 'Photo length (pixels)', ylab = 'Surface height (pixels)')
    points(y0[maxs_t0] ~ x0[maxs_t0])
    points(y0[mins_t0] ~ x0[mins_t0])
    
    rippleRange = maxs_t0 > min(mins_t0) & maxs_t0 < max(mins_t0)
    
    n_ripples = length(mins_t0) - 1
    for(i_ripple in 1:n_ripples){
      trough1 = mins_t0[i_ripple]
      peak = maxs_t0[rippleRange][i_ripple]
      trough2 = mins_t0[i_ripple + 1]
      
      rippleLength.pixels[i_ripple] = trough2 - trough1
      asymmetry.prop[i_ripple] = abs((peak - trough1) - (trough2 - peak))/(trough2 - trough1)
      rippleHeight.pixels[i_ripple] = y0[peak] - mean(c(y0[trough1], y0[trough2]))
      photoNumber[i_ripple] = i_col
      
      # Ripple area
      rippleBase = approx(x = c(trough1, trough2), y = y0[c(trough1, trough2)], n = 1 + (trough2 - trough1))$y
      rippleTop = y0[trough1:trough2]
      rippleTop[rippleTop < rippleBase] = rippleBase[rippleTop < rippleBase]
      rippleArea.pixels2[i_ripple] = sum((rippleTop - rippleBase))
      
      if(plot == T){
        ## --- Plot ripple area ---
        lines(rippleTop ~ x0[trough1:trough2], type = 'l', ylim = c(-10,10), xlim = c(0, dim(M)[1]), col = 2)
        points(y0[c(trough1, peak, trough2)] ~ x0[c(trough1, peak, trough2)], col = 2)
        lines(rippleBase ~ x0[trough1:trough2], type = 'l', col = 2, lty = 2)
        ## --- Plot ripple area ---
      }
      
    }
    
    # --------------------
    i_t1 = i_t0 + interval #i_col + runif(n = 1, min = 1, max = 20)
    y1 = M[,i_t1]
    x1 = 1:length(y1)  
    
    # Find peaks t1
    findPeaks = findpeaks(y1)
    maxs_t1 = findPeaks[,2]
    mins_t1 = findPeaks[,4]
    maxs_t1 = maxs_t1[maxs_t1 != length(y1)]
    mins_t1 = mins_t1[mins_t1 != length(y1)]
    
    plot(y1 ~ x1, type = 'l', ylim = c(-10,10), xlab = 'Photo length (pixels)', ylab = 'Surface height (pixels)')
    points(y1[maxs_t1] ~ x1[maxs_t1])
    points(y1[mins_t1] ~ x1[mins_t1])
    
    rippleRange = maxs_t1 > min(mins_t1) & maxs_t1 < max(mins_t1)
    
    n_ripples = length(mins_t1) - 1
    for(i_ripple in 1:n_ripples){
      trough1 = mins_t1[i_ripple]
      peak = maxs_t1[rippleRange][i_ripple]
      trough2 = mins_t1[i_ripple + 1]
      
      rippleLength.pixels[i_ripple] = trough2 - trough1
      asymmetry.prop[i_ripple] = abs((peak - trough1) - (trough2 - peak))/(trough2 - trough1)
      rippleHeight.pixels[i_ripple] = y1[peak] - mean(c(y1[trough1], y1[trough2]))
      photoNumber[i_ripple] = i_col
      
      # Ripple area
      rippleBase = approx(x = c(trough1, trough2), y = y1[c(trough1, trough2)], n = 1 + (trough2 - trough1))$y
      rippleTop = y1[trough1:trough2]
      rippleTop[rippleTop < rippleBase] = rippleBase[rippleTop < rippleBase]
      rippleArea.pixels2[i_ripple] = sum((rippleTop - rippleBase))
      
      if(plot == T){
        ## --- Plot ripple area ---
        lines(rippleTop ~ x1[trough1:trough2], type = 'l', ylim = c(-10,10), xlim = c(0, dim(M)[1]), col = 2)
        points(y1[c(trough1, peak, trough2)] ~ x1[c(trough1, peak, trough2)], col = 2)
        lines(rippleBase ~ x1[trough1:trough2], type = 'l', col = 2, lty = 2)
        ## --- Plot ripple area ---
      }
      
    }
    
    
    # ---------------------
    
    # Determine if we are following the peaks or the troughs
    for(i_run in 1:2){
      if(i_run == 1){
        peaks_t1 = maxs_t1
        peaks_t0 = maxs_t0
      } else {
        peaks_t1 = mins_t1
        peaks_t0 = mins_t0
      }
      
      # Determine if t1 or t0 has more peaks
      if(length(peaks_t1) <= length(peaks_t0)){
        t1 = peaks_t1
        t0 = peaks_t0
        switched = F
      } else {
        t1 = peaks_t0
        t0 = peaks_t1
        switched = T
      }
      
      partnerIndex = partnerDiff = rep(NA, times = length(t1))
      for(i_peak in 1:length(t1)){
        if(switched == T){
          partnerOptions = (t1[i_peak] - t0) < 0
        } else {
          partnerOptions = (t1[i_peak] - t0) > 0
        }
        if(sum(partnerOptions) > 0){
          partnerIndex[i_peak] = which(min(abs(t1[i_peak] - t0[partnerOptions])) == abs(t1[i_peak] - t0))[1]
          partnerDiff[i_peak] = abs(t1[i_peak] - t0[partnerIndex[i_peak]])
        }
      }
      duplicates = partnerIndex[duplicated(partnerIndex)]
      duplicates = duplicates[!is.na(duplicates)]
      while(length(duplicates) > 0){
        filter = partnerIndex == duplicates[1] & !is.na(partnerIndex)
        wrongPartner = which.max(partnerDiff[filter])
        partnerIndex[filter][wrongPartner] = NA
        partnerDiff[filter][wrongPartner] = NA
        duplicates = duplicates[-1]
      }
      t0 = t0[partnerIndex]
      
      if(switched == T){
        t = t0
        t0 = t1
        t1 = t
      }
      
      # -------
      # # Plotting
      # if(i_t0 %% 20 == 0){
      #   if(i_run == 1){
      #     plot(y0 ~ x0, type = 'l', ylim = c(-10,10), xlab = 'Photo length (pixels)', ylab = 'Surface height (pixels)')
      #     points(y0[maxs_t0] ~ x0[maxs_t0], pch = 21, bg = col[250], cex = 0.8)
      #     points(y0[mins_t0] ~ x0[mins_t0], pch = 21, bg = col[750], cex = 0.8)
      #     lines(y1 ~ x1, lty = 2)
      #     points(y1[maxs_t1] ~ x1[maxs_t1], pch = 21, bg = col[250])
      #     points(y1[mins_t1] ~ x1[mins_t1], pch = 21, bg = col[750])
      #     for(i_peak in 1:length(t1)){
      #       lines(x =  c(x0[t0][i_peak], x1[t1][i_peak]), y = c(y0[t0][i_peak], y1[t1][i_peak]), col = col[250], lwd = 2)
      #     }
      #   } else {
      #     for(i_peak in 1:length(t1)){
      #       lines(x =  c(x0[t0][i_peak], x1[t1][i_peak]), y = c(y0[t0][i_peak], y1[t1][i_peak]), col = col[750], lwd = 2)
      #     }
      #   }
      # }
      # -------
      
      # Save migration information into dataframe
      migration.pixels_photo = c(migration.pixels_photo, t1 - t0)
      if(i_run == 1){
        peakLabel = c(peakLabel, rep('peak', times = length(t1)))
      } else {
        peakLabel = c(peakLabel, rep('trough', times = length(t1)))
      }
      photoNumber = c(photoNumber, rep(i_t0, times = length(t1)))
      
    }
    print(i_t0)
  }
  experimentName = rep(dir(filteredOutputDirectory, pattern = '.rda'))[i_exp]
  experimentName = unlist(strsplit(experimentName, split = '_output.rda'))
  experiment = rep(experimentName, times = length(migration.pixels_photo))
  d = data.frame(migration.pixels_photo, peakLabel, photoNumber, experiment)
  D = rbind(D, d)
  print(i_exp)
}
d = D

d = d[d$migration.pixels_photo > 0 & !is.na(d$migration.pixels_photo),]
write.csv(d, 'rippleMigrationRateConstantFlow.csv')


# -------------------------------
# Plot 3 - Histograms (Ripple migration)
setwd('SET_TO_CORRECT_DIRECTORY_PATH')
d = read.csv('rippleMigrationRateConstantFlow_2.csv')
d$experiment[d$experiment == "ShellRacetrack_constantflow_shell_15.0%_1"] = "ShellRacetrack_constantflow_shell_15.0%_2"
d$experiment = factor(d$experiment)

n_experiments = length(levels(d$experiment))
col = viridis(n = n_experiments)

d$migration.cm_photo = d$migration.pixels_photo*pixelsToCM
d$migration.cm_min = d$migration.cm_photo/(timestepsToMinutes*interval.photos)
d$time.minutes = d$photoNumber*timestepsToMinutes
d$rippleLength_t0.cm = d$rippleLength_t0.pixels*pixelsToCM
d$rippleHeight_t0.cm = d$rippleHeight_t0.pixels*pixelsToCM
d$rippleArea_t0.pixels2 = d$rippleArea_t0.pixels2*pixelsToCM

shellContentLabel = rep(NA, times = n_experiments)
for(i in 1:n_experiments){
  shellContentLabel[i] = as.numeric(unlist(strsplit(strsplit(levels(d$experiment), split = '_')[[i]][4], split = '%')))
}

index = 1:7#c(1,5,2,3,4,6,7)
yv = d$migration.cm_min
yv[] = NA
xv = d$experiment
plot(yv ~ xv, log = 'x', ylim = c(0.00001,1), horizontal = T,
     yaxt = 'n', xaxt = 'n', 
     xlab = 'Sediment shell content (%)', ylab = expression('Ripple migration rate (cm min'^-1*')'))
axis(side = 1, at = 10^seq(-10,10,1), labels = 10^seq(-10,10,1))
axis(side = 2, at = 1:n_experiments, labels = shellContentLabel, tick = F)
meanMigrationRate = rep(NA, times = n_experiments)
for(i in 1:n_experiments){
  
  filter = d$experiment == levels(d$experiment)[i] & d$photoNumber > 300
  breaks = seq(-20,10,0.04)
  r = runif(n = length(d$migration.cm_min[filter]), min = -0.005, max = 0.005)
  y = hist(log(abs(d$migration.cm_min[filter] + r)), breaks = breaks, plot = F)$density
  x = hist(log(abs(d$migration.cm_min[filter] + r)), breaks = breaks, plot = F)$mids
  
  # rect(xright = y + i, xleft = i, ybottom = exp(x) * 0.95, ytop = exp(x) * 1.05, col = alpha(col[i], 0.7), lty = 0)
  # rect(ytop = y + (n_experiments - i + 0.8), ybottom = (n_experiments - i + 0.8), xright = exp(x) * 0.95, xleft = exp(x) * 1.05, col = alpha(col[i], 0.7), lty = 0)
  rect(ytop = y + index[i] - 0.4, ybottom = index[i] - 0.4, xright = exp(x - diff(breaks)/2), xleft = exp(x + diff(breaks)/2), col = alpha(col[index[i]], 0.7), lty = 0)
  
  # meanMigrationRate[i] = exp(mean(log(d$migration.cm_min[filter])))
  meanMigrationRate[i] = mean(d$migration.cm_min[filter])
  lines(y = c(index[i]+0.05 - 0.4,index[i] + 0.8 - 0.4), x = c(meanMigrationRate[i],meanMigrationRate[i]), col = alpha(col[index[i]], 0.7), lwd = 3)
}

# Regression on migration rate against shell content
plot(meanMigrationRate ~ shellContentLabel, 
     #ylim = c(5,20), xlim = c(-5,25),
     log = 'y', pch = 21, bg = col, #xaxt = 'n',
     ylab = expression('Migration rate (cm min'^-1*')'), xlab = 'Shell content (%)')
# axis(side = 1, labels = c(0,5,10,15,20,50), at = c(0,5,10,15,20,50))
     
m = lm(log(meanMigrationRate) ~ shellContentLabel)
summary(m)
a = m$coefficients[1]
b = m$coefficients[2]
xv = seq(min(shellContentLabel), max(shellContentLabel), length.out = 1000)
yv = exp(a + b*xv)
lines(yv ~ xv, lty = 2, col = 'grey', lwd = 2)
text(x = 25, y = 0.1, expression('(F'['1,4']*'= 295.2, R'^2*'= 0.983, n = 6, p < 0.0001)'))
text(x = 25, y = 0.009, expression('Migration rate = 0.1 * e'^' -0.05 * Shell content (%)'))
