
inputDirectory = 'SET_TO_CORRECT_DIRECTORY_PATH'
outputDirectory = 'SET_TO_CORRECT_DIRECTORY_PATH'
filteredOutputDirectory = 'SET_TO_CORRECT_DIRECTORY_PATH'
dataFrameDirectory = 'SET_TO_CORRECT_DIRECTORY_PATH'

# # ---------------------------
# Section 4: Calculate ripple migration
# # ---------------------------

library(pracma)
library(viridis)
col = viridis(1000)
interval = 24

DD = data.frame(NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA)[-1,]
names(DD) = c("experiment", "photoNumber", "migration.pixels_photo", "interval.photos",
              "rippleLength_t0.pixels", "asymmetry_t0.prop", "rippleHeight_t0.pixels", "rippleArea_t0.pixels2", 
              "rippleLength_t1.pixels", "asymmetry_t1.prop", "rippleHeight_t1.pixels", "rippleArea_t1.pixels2")

n_experiments = length(dir(filteredOutputDirectory, pattern = '.rda'))

i_exp = 1
for(i_exp in 1:n_experiments){
  setwd(filteredOutputDirectory)
  load(file = dir(filteredOutputDirectory, pattern = '.rda')[i_exp])
  
  experimentName = rep(dir(filteredOutputDirectory, pattern = '.rda'))[i_exp]
  experimentName = unlist(strsplit(experimentName, split = '_output.rda'))
  
  D = data.frame(NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA)[-1,]
  names(D) = c("experiment", "photoNumber", "migration.pixels_photo", "interval.photos",
               "rippleLength_t0.pixels", "asymmetry_t0.prop", "rippleHeight_t0.pixels", "rippleArea_t0.pixels2", 
               "rippleLength_t1.pixels", "asymmetry_t1.prop", "rippleHeight_t1.pixels", "rippleArea_t1.pixels2")
  
  
  n_cols = dim(M)[2]
  for(i_t0 in 1:(n_cols - interval - 1)){
    
    # --------------------
    # i_t0 = runif(n = 1, min = 1, max = n_cols - interval)
    y0 = M[,i_t0]
    x0 = 1:length(y0)  
    
    # Find peaks t0
    findPeaks = findpeaks(y0)
    maxs_t0 = findPeaks[,2]
    mins_t0 = findPeaks[,4]
    maxs_t0 = maxs_t0[maxs_t0 != length(y0)]
    mins_t0 = mins_t0[mins_t0 != length(y0)]
    
    i_t1 = i_t0 + interval #i_col + runif(n = 1, min = 1, max = 20)
    y1 = M[,i_t1]
    x1 = 1:length(y1)  
    
    # Find peaks t1
    findPeaks = findpeaks(y1)
    maxs_t1 = findPeaks[,2]
    mins_t1 = findPeaks[,4]
    maxs_t1 = maxs_t1[maxs_t1 != length(y1)]
    mins_t1 = mins_t1[mins_t1 != length(y1)]
    
    # Only consider the ripples which have a trough on either side within frame
    y0[-(mins_t0[1]:mins_t0[length(mins_t0)])] = NA
    y1[-(mins_t1[1]:mins_t1[length(mins_t1)])] = NA
    maxs_t1 = maxs_t1[maxs_t1 > mins_t1[1] & maxs_t1 < mins_t1[length(mins_t1)]]
    maxs_t0 = maxs_t0[maxs_t0 > mins_t0[1] & maxs_t0 < mins_t0[length(mins_t0)]]
    # ---------------------
    
    # Determine if t1 or t0 has more peaks
    if(length(maxs_t1) <= length(maxs_t0)){
      t1 = maxs_t1
      t0 = maxs_t0
      switched = F
    } else {
      t1 = maxs_t0
      t0 = maxs_t1
      switched = T
    }
    
    # Determine which ripples are the same between t0 and t1
    partnerIndex = partnerDiff = rep(NA, times = length(t1))
    for(i_peak in 1:length(t1)){
      if(switched == T){
        partnerOptions = (t1[i_peak] - t0) < 10
      } else {
        partnerOptions = (t1[i_peak] - t0) > -10
      }
      if(sum(partnerOptions) > 0){
        partnerIndex[i_peak] = which(min(abs(t1[i_peak] - t0[partnerOptions])) == abs(t1[i_peak] - t0))[1]
        partnerDiff[i_peak] = abs(t1[i_peak] - t0[partnerIndex[i_peak]])
      }
    }
    duplicates = partnerIndex[duplicated(partnerIndex)]
    duplicates = duplicates[!is.na(duplicates)]
    while(length(duplicates) > 0){
      filter = partnerIndex == duplicates[1] & !is.na(partnerIndex)
      wrongPartner = which.max(partnerDiff[filter])
      partnerIndex[filter][wrongPartner] = NA
      partnerDiff[filter][wrongPartner] = NA
      duplicates = duplicates[-1]
    }
    t0 = t0[partnerIndex]
    
    filter = !is.na(t1) & !is.na(t0)
    t0 = t0[filter]
    t1 = t1[filter]
    
    if(switched == T){
      t = t0
      t0 = t1
      t1 = t
    }
    
    # ## -------
    # # Plotting
    # if(i_t0 %% 24 == 0){
    #   plot(y0 ~ x0, type = 'l', ylim = c(-10,10), xlim = range(x0),
    #        xlab = 'Photo length (pixels)', ylab = 'Surface height (pixels)')
    #   points(y0[maxs_t0] ~ x0[maxs_t0], pch = 21, bg = col[250], cex = 0.8)
    #   points(y0[mins_t0] ~ x0[mins_t0], pch = 21, bg = col[750], cex = 0.8)
    #   lines(y1 ~ x1, lty = 2)
    #   points(y1[maxs_t1] ~ x1[maxs_t1], pch = 21, bg = col[250])
    #   points(y1[mins_t1] ~ x1[mins_t1], pch = 21, bg = col[750])
    #   for(i_peak in 1:length(t1)){
    #     lines(x =  c(x0[t0][i_peak], x1[t1][i_peak]), y = c(y0[t0][i_peak], y1[t1][i_peak]), col = col[250], lwd = 2)
    #   }
    # }
    # ## -------

    
    if(length(peak[!is.na(t0)]) > 0){
      # Determine the ripple parameters of either peak that was tracked in time
      # Ripple parameters: T0
      rippleLength_t0.pixels = c()
      asymmetry_t0.prop = c()
      rippleHeight_t0.pixels = c()
      rippleArea_t0.pixels2 = c()
      i_peak = 1
      for(i_peak in 1:length(t0)){
        peak = t0[i_peak]
        trough1 = max(mins_t0[mins_t0 < peak])
        trough2 = min(mins_t0[mins_t0 > peak])
        
        rippleLength_t0.pixels[i_peak] = trough2 - trough1
        asymmetry_t0.prop[i_peak] = abs((peak - trough1) - (trough2 - peak))/(trough2 - trough1)
        rippleHeight_t0.pixels[i_peak] = y0[peak] - mean(c(y0[trough1], y0[trough2]))
        
        # Ripple area
        rippleTop_t0 = y0[trough1:trough2]
        rippleBase_t0 = approx(x = x0[c(trough1, trough2)], y = y0[c(trough1, trough2)], n = 1 + (trough2 - trough1))$y
        rippleBase_t0[rippleBase_t0 > rippleTop_t0] = rippleTop_t0[rippleBase_t0 > rippleTop_t0]
        rippleArea_t0.pixels2[i_peak] = sum((rippleTop_t0 - rippleBase_t0))
        
        
        # ## --- Plot ripple area ---
        # lines(rippleTop_t0 ~ x0[trough1:trough2], type = 'l', ylim = c(-10,10), xlim = c(0, dim(M)[1]), col = 'red')
        # points(y0[c(trough1, peak, trough2)] ~ x0[c(trough1, peak, trough2)], col = 'red')
        # lines(rippleBase_t0 ~ x0[trough1:trough2], type = 'l', col = 'red', lty = 2)
        # ## --- Plot ripple area ---
      }
      
      # Ripple parameters: T1
      rippleLength_t1.pixels = c()
      asymmetry_t1.prop = c()
      rippleHeight_t1.pixels = c()
      rippleArea_t1.pixels2 = c()
      i_peak = 1
      for(i_peak in 1:length(t1)){
        peak = t1[i_peak]
        trough1 = max(mins_t1[mins_t1 < peak])
        trough2 = min(mins_t1[mins_t1 > peak])
        
        rippleLength_t1.pixels[i_peak] = trough2 - trough1
        asymmetry_t1.prop[i_peak] = abs((peak - trough1) - (trough2 - peak))/(trough2 - trough1)
        rippleHeight_t1.pixels[i_peak] = y1[peak] - mean(c(y1[trough1], y1[trough2]))
        
        # Ripple area
        rippleTop_t1 = y1[trough1:trough2]
        rippleBase_t1 = approx(x = x1[c(trough1, trough2)], y = y1[c(trough1, trough2)], n = 1 + (trough2 - trough1))$y
        rippleBase_t1[rippleBase_t1 > rippleTop_t1] = rippleTop_t1[rippleBase_t1 > rippleTop_t1]
        rippleArea_t1.pixels2[i_peak] = sum((rippleTop_t1 - rippleBase_t1))
        
        
        # ## --- Plot ripple area ---
        # lines(rippleTop_t1 ~ x1[trough1:trough2], type = 'l', ylim = c(-10,10), xlim = c(0, dim(M)[1]), col = 'red')
        # points(y1[c(trough1, peak, trough2)] ~ x1[c(trough1, peak, trough2)], col = 'red')
        # lines(rippleBase_t1 ~ x1[trough1:trough2], type = 'l', col = 'red', lty = 2)
        # ## --- Plot ripple area ---
      }
      # ----------------------
      
      # Save ripple parameters & migration rate information into dataframe
      migration.pixels_photo = abs(t1 - t0)
      photoNumber = rep(i_t0, times = length(migration.pixels_photo))
      experiment = rep(experimentName, times = length(migration.pixels_photo))
      interval.photos = rep(interval, times = length(migration.pixels_photo))
      
      d = data.frame(experiment, 
                     photoNumber,
                     migration.pixels_photo,
                     rippleLength_t0.pixels,
                     asymmetry_t0.prop,
                     rippleHeight_t0.pixels,
                     rippleArea_t0.pixels2,
                     rippleLength_t1.pixels,
                     asymmetry_t1.prop,
                     rippleHeight_t1.pixels,
                     rippleArea_t1.pixels2,
                     interval.photos)
      D = rbind(D, d)
    }
    print(i_t0)
  }
  DD = rbind(DD, D)
  print(i_exp)
}
d = DD

# d$migration.pixels_photo = abs(d$migration.pixels_photo)
# d = d[d$migration.pixels_photo > 0 & !is.na(d$migration.pixels_photo),]
setwd(dataFrameDirectory)
# write.csv(d, 'rippleMigrationRateConstantFlow_2.csv')
# write.csv(d, 'rippleMigrationRateTidalFlow_2.csv')

# # ---------------------------
# Section 5: Ripple parameters figures (Tidal flow)
# # ---------------------------
library(viridis)
library(raster)

setwd(dataFrameDirectory)
d = read.csv('rippleMigrationRateTidalFlow_2.csv')

library(scales)
n_experiments = length(unique(d$experiment))
col = viridis(n = n_experiments)

# Plot 1 - Regression
pixelsToCM = 0.02
d$rippleArea_t0.cm2 = d$rippleArea_t0.pixels2*(pixelsToCM)^2
d$rippleHeight_t0.cm = d$rippleHeight_t0.pixels*(pixelsToCM)

m = lm(log(d$rippleArea_t0.cm2) ~ log(d$rippleHeight_t0.cm))
summary(m)
a = m$coefficients[1]
b = m$coefficients[2]
xv = seq(min(d$rippleHeight_t0.cm), max(d$rippleHeight_t0.cm), length.out = 1000)
yv = exp(a + b*log(xv))
par(mar = c(5,5,4,4))
plot(yv ~ xv, lty = 1, lwd = 3, col = 'grey', log = 'yx', type = 'l',
     #ylim = c(0.00001,1000), xlim = c(0.00005, 10),
     ylab = expression('Ripple area (cm'^2*')'), xlab = 'Ripple height (cm)', xaxt = 'n', yaxt = 'n')
points(d$rippleArea_t0.cm2 ~ d$rippleHeight_t0.cm, pch = '.', col = alpha(col[d$experiment],0.1), cex = 2)
axis(side = 1, at = 10^seq(-10,10, 1), label = 10^seq(-10,10, 1))
axis(side = 2, at = 10^seq(-10,10, 1), label = 10^seq(-10,10, 1))

y = exp(tapply(log(d$rippleArea_t0.pixels2), list(d$photoNumber,d$experiment), mean))

yWindow = array(NA, dim = dim(y))
xWindow = array(NA, dim = dim(y))
interval = 100
for(i_exp in 1:n_experiments){
  start = 0
  end = start + interval
  while(end < length(y[,i_exp])){
    start = start + 1
    end = start + interval
    
    yWindow[start,i_exp] = mean(y[start:end,i_exp], na.rm = T)
    xWindow[start,i_exp] = mean(start:end, na.rm = T)
  }  
}  

plot(y[,1], ylim = c(1,150), pch = '.', cex = 1, col = col[1], log = '')
for(i_exp in 2:n_experiments){
  points(y[,i_exp], pch = '.', cex = 1, col = col[i_exp])
  # lines(yWindow[,i_exp] ~ xWindow[,i_exp], lwd = 3, col = col[i_exp])
}

lines(yWindow[,1] ~ xWindow[,1], ylim = c(1,40), col = col[1], lwd = 3)
for(i_exp in 2:n_experiments){
  lines(yWindow[,i_exp] ~ xWindow[,i_exp], lwd = 3, col = col[i_exp])
}


plot(raster(log(y)), col = viridis(1000))




# # ---------------------------
# Section 6: Ripple migration figures (Tidal flow)
# # ---------------------------

setwd(dataFrameDirectory)
d = read.csv('rippleMigrationRateTidalFlow_2.csv')

n_experiments = length(unique(d$experiment))
shellContentLabel = rep(NA, times = n_experiments)
for(i in 1:n_experiments){
  shellContentLabel[i] = as.numeric(unlist(strsplit(strsplit(levels(d$experiment), split = '_')[[i]][4], split = '%')))
}

d$shellContent.percent = NA
for(i in 1:n_experiments){
  d$shellContent.percent[d$experiment == levels(d$experiment)[i]] = shellContentLabel[i]
}

d$shellContent.percent = d$experiment
d$migration.pixels_photo[d$rippleArea_t0.pixels2 < 10] = 0

migration = d$migration.pixels_photo + runif(n = length(d$migration.pixels_photo), min = -0.5, max = 0.5)
plot(migration ~ d$photoNumber, pch = '.', cex = 3, col = alpha(col[d$experiment],0.3))



yWindow = array(NA, dim = c(max(d$photoNumber) - interval, n_experiments))
xWindow = array(NA, dim = dim(yWindow))
interval = 10
i_exp = 1
for(i_exp in 1:n_experiments){
  start = 0
  end = start + interval
  
  filter = d$experiment == unique(d$experiment)[i_exp]# &d$migration.pixels_photo > 0
  y = d$migration.pixels_photo[filter]
  
  while(end < max(d$photoNumber)){
    start = start + 1
    end = start + interval
    
    yWindow[start,i_exp] = mean(y[d$photoNumber[filter] >= start & d$photoNumber[filter] < end])
    xWindow[start,i_exp] = mean(start:end)
  }  
  print(paste(i_exp,'/',n_experiments))
}


plot(yWindow[,1] ~ xWindow[,1], ylim = c(0,50), col = col[1], pch = '.', cex = 2)
for(i in 1:n_experiments){
  points(yWindow[,i] ~ xWindow[,i], col = col[i], pch = '.', cex = 2)
}

n_experiments = length(unique(d$shellContent.percent))
col = viridis(n = n_experiments)

plot(raster(yWindow), col = viridis(1000), zlim = c(0,50))

# ---------------------------------------------------
setwd(outputDirectory)
n_experiments = length(dir(pattern = '.rda'))
shellContentLabel = rep(NA, times = n_experiments)
for(i in 1:n_experiments){
  shellContentLabel[i] = as.numeric(unlist(strsplit(strsplit(levels(d$experiment), split = '_')[[i]][4], split = '%')))
}

resizeFactor = 8
pixelsToCM = 0.02
timestepsToMinutes = 10/60
interval.photos = 24

migrationRate.cm_minute = yWindow*(pixelsToCM/timestepsToMinutes*interval.photos)
time.minutes = 1:dim(migrationRate.cm_minute)[1]*timestepsToMinutes


par(mfrow = c(2,1))
i_exp = 5
for(i_exp in 1:n_experiments){
  load(dir()[i_exp])
  
  par(mar = c(2,0,1,3))
  col = viridis(1000)
  plot(raster(M), col = col, zlim = c(-4,4), box = F, axes = F, main = shellContentLabel[i_exp])
  labels = seq(0,2000,300)
  axis(side = 1, at = labels/dim(M)[2], labels = labels*timestepsToMinutes)
  axis(side = 1, line = 1.5, at = 0.5, labels = 'Run time (minutes)', tick = F)
  labels = seq(0, 500, 100)
  axis(side = 2, at = labels/dim(M)[1], labels = labels*pixelsToCM*resizeFactor)
  axis(side = 2, line = 1.5, at = 0.5, labels = 'Position in channel (cm)', tick = F)
  
  par(mar = c(5,5,3,3))
  col = viridis(n_experiments)
  plot(migrationRate.cm_minute[,i_exp] ~ time.minutes, 
       ylim = c(0,150), pch = '.', cex = 2, col = col[i_exp], log = '', main = shellContentLabel[i_exp],
       ylab = 'Migration rate (minutes)', )
  lines(migrationRate.cm_minute[,i_exp] ~ time.minutes, 
        col = col[i_exp], lwd = 3)
}

plot(d$rippleArea_t0.pixels2 ~ d$migration.pixels_photo, log = '', pch = '.', cex = 2, col = alpha('black',0.5))

plot(abs(d$migration.pixels_photo))
