
# # ---------------------------
# Section 3: Ripple parameters figures (Constant flow)
# # ---------------------------
set.seed(1)

setwd('SET_TO_CORRECT_DIRECTORY_PATH')
# setwd('SET_TO_CORRECT_DIRECTORY_PATH')
d = read.csv('rippleMigrationRateConstantFlow_2.csv')
d$experiment[d$experiment == "ShellRacetrack_constantflow_shell_15.0%_1"] = "ShellRacetrack_constantflow_shell_15.0%_2"
d$experiment = factor(d$experiment)

n_experiments = length(levels(d$experiment))
library(scales)
library(viridis)
col = viridis(n = n_experiments)

resizeFactor = 8
pixelsToCM = 0.02
timestepsToMinutes = 10/60
interval.photos = 24

# Ripple dimensions
# d$rippleArea_t0.cm2 = d$rippleArea_t0.pixels2*(pixelsToCM*resizeFactor)^2
d$rippleLength_t0.cm = d$rippleLength_t0.pixels*(pixelsToCM*resizeFactor)
d$rippleHeight_t0.cm = d$rippleHeight_t0.pixels#*(pixelsToCM*resizeFactor)

# d$rippleLength_t0.pixels

# Ripple migration rate
d$time.minutes = d$photoNumber*timestepsToMinutes
d$migration.cm_photo = d$migration.pixels_photo*(resizeFactor*pixelsToCM)
d$migration.cm_min = d$migration.cm_photo/(timestepsToMinutes*interval.photos)

# Bed load transport
BLTparameter = 0.6
d$bedloadTransport.cm2_min = d$migration.cm_min*d$rippleHeight_t0.cm*BLTparameter

shellContentLabel = rep(NA, times = n_experiments)
for(i in 1:n_experiments){
  shellContentLabel[i] = as.numeric(unlist(strsplit(strsplit(levels(d$experiment), split = '_')[[i]][4], split = '%')))
}

# # Plot 1 - Regression
# 
# m = lm(log(d$rippleArea_t0.cm2) ~ log(d$rippleHeight_t0.cm))
# summary(m)
# a = m$coefficients[1]
# b = m$coefficients[2]
# xv = seq(min(d$rippleHeight_t0.cm), max(d$rippleHeight_t0.cm), length.out = 1000)
# yv = exp(a + b*log(xv))
# plot(yv ~ xv, lty = 1, lwd = 3, col = 'grey', log = 'yx', type = 'l',
#      #ylim = c(0.00001,1000), xlim = c(0.00005, 10),
#      ylab = 'Ripple area (cm^2)', xlab = 'Ripple height (cm)', xaxt = 'n', yaxt = 'n')
# points(d$rippleArea_t0.cm2 ~ d$rippleHeight_t0.cm, pch = '.', col = alpha(col[d$experiment],0.1), cex = 2)
# axis(side = 1, at = 10^seq(-10,10, 1), label = 10^seq(-10,10, 1))
# axis(side = 2, at = 10^seq(-10,10, 1), label = 10^seq(-10,10, 1))

# Plot 2 - Histograms

index = 1:n_experiments
yv = d$rippleHeight_t0.pixels
yv[] = NA
xv = d$experiment

tiff(filename = 'rippleHeight_histograms.tif', width = 15,height = 15, units = 'cm', res = 300)
par(mar = c(5,5,4,4))
plot(yv ~ xv, log = 'x', ylim = c(0.001, 10), horizontal = T,
     yaxt = 'n', xaxt = 'n', 
     xlab = 'Sediment shell content (%)',
     ylab = 'Ripple Height (cm)')
     #ylab = expression('Ripple Heigt (cm'^2*')'))
axis(side = 1, at = 10^seq(-10,10,1), labels = 10^seq(-10,10,1))
axis(side = 2, at = 1:n_experiments, labels = shellContentLabel, tick = F)
mean = sd = se = rep(NA, times = n_experiments)
for(i in 1:n_experiments){
  
  filter = d$experiment == levels(d$experiment)[i] & d$photoNumber > 300
  breaks = seq(-20,10,0.03)
  y = hist(log(d$rippleHeight_t0.pixels)[filter], breaks = breaks, plot = F)$density*0.5
  x = hist(log(d$rippleHeight_t0.pixels)[filter], breaks = breaks, plot = F)$mids
  
  rect(ytop = y + index[i] - 0.37, ybottom = index[i] - 0.37, xright = exp(x - diff(breaks)/2), xleft = exp(x + diff(breaks)/2), col = alpha(col[index[i]], 0.7), lty = 0)
  
  mean[i] = mean(d$rippleHeight_t0.pixels[filter])
  sd[i] = sd(d$rippleHeight_t0.pixels[filter])
  se[i] = sd[i]/sqrt(length(d$rippleHeight_t0.pixels[filter]))
  
  lines(y = c(index[i]+0.05 - 0.4,index[i] + 0.8 - 0.4), x = c(mean[i],mean[i]), col = alpha(col[index[i]], 1), lwd = 3)
}
setwd('SET_TO_CORRECT_DIRECTORY_PATH')
dev.off()

print(paste(round(mean[1],2),'', round(se[1],4)))
print(paste(round(mean[6],2),'', round(se[6],4)))

# Plot 1 - Regression
tiff(filename = 'rippleHeight_regression.tif', width = 15,height = 15, units = 'cm', res = 300)
par(mar = c(5,5,4,4))
plot(mean ~ shellContentLabel, log = 'y', pch = 21, bg = col, #xaxt = 'n',
     ylim = c(0.2,2),
     ylab = 'Ripple Height (cm)', xlab = 'Shell content (%)')
m = lm(log(mean) ~ shellContentLabel)
summary(m)
a = m$coefficients[1]
b = m$coefficients[2]
xv = seq(min(shellContentLabel), max(shellContentLabel), length.out = 1000)
yv = exp(a + b*xv)
lines(yv ~ xv, lty = 2, col = 'grey', lwd = 2)
text(x = 25, y = 1.9, expression('(F'['1,4']*'= 19.16, R'^2*'= 0.784, n = 6, p < 0.0001)'))
text(x = 25, y = 0.21, expression('Ripple height = 1.78 * e'^' -0.04 * Shell content (%)'))
# arrows(x0 = shellContentLabel, x1 = shellContentLabel, 
#        y0 = mean + se, y1 = mean - se, 
#        code = 3, angle = 90, length = 0.05)
setwd('SET_TO_CORRECT_DIRECTORY_PATH')
dev.off()


# -------------------------------
# Plot 3 - Histograms (Ripple migration)

index = 1:7#c(1,5,2,3,4,6,7)
yv = d$migration.cm_min
yv[] = NA
xv = d$experiment

tiff(filename = 'rippleMigration_histogram.tif', width = 15,height = 15, units = 'cm', res = 300)
par(mar = c(5,5,4,4))
plot(yv ~ xv, log = 'x', ylim = c(0.0001,10), horizontal = T,
     yaxt = 'n', xaxt = 'n', 
     xlab = 'Sediment shell content (%)', ylab = expression('Ripple migration rate (cm min'^-1*')'))
axis(side = 1, at = 10^seq(-10,10,1), labels = 10^seq(-10,10,1))
axis(side = 2, at = 1:n_experiments, labels = shellContentLabel, tick = F)
meanMigrationRate = rep(NA, times = n_experiments)
for(i in 1:n_experiments){
  
  filter = d$experiment == levels(d$experiment)[i] & d$photoNumber > 300
  breaks = seq(-20,100,0.04)
  r = runif(n = length(d$migration.cm_min[filter]), min = -0.1, max = 0.1)
  y = hist(log(abs(d$migration.cm_min[filter] + r)), breaks = breaks, plot = F)$density
  x = hist(log(abs(d$migration.cm_min[filter] + r)), breaks = breaks, plot = F)$mids
  
  # rect(xright = y + i, xleft = i, ybottom = exp(x) * 0.95, ytop = exp(x) * 1.05, col = alpha(col[i], 0.7), lty = 0)
  # rect(ytop = y + (n_experiments - i + 0.8), ybottom = (n_experiments - i + 0.8), xright = exp(x) * 0.95, xleft = exp(x) * 1.05, col = alpha(col[i], 0.7), lty = 0)
  rect(ytop = y + index[i] - 0.37, ybottom = index[i] - 0.37, xright = exp(x - diff(breaks)/2), xleft = exp(x + diff(breaks)/2), col = alpha(col[index[i]], 0.7), lty = 0)
  
  # meanMigrationRate[i] = exp(mean(log(d$migration.cm_min[filter])))
  meanMigrationRate[i] = mean(d$migration.cm_min[filter])
  lines(y = c(index[i]+0.05 - 0.4,index[i] + 0.8 - 0.4), x = c(meanMigrationRate[i],meanMigrationRate[i]), col = alpha(col[index[i]], 1), lwd = 3)
}
dev.off()

# Regression on migration rate against shell content
tiff(filename = 'rippleMigration_regression.tif', width = 15,height = 15, units = 'cm', res = 300)
par(mar = c(5,5,4,4))
plot(meanMigrationRate ~ shellContentLabel, 
     ylim = c(0.05,1),
     #ylim = c(5,20), xlim = c(-5,25),
     log = 'y', pch = 21, bg = col, #xaxt = 'n',
     ylab = expression('Migration rate (cm min'^-1*')'), xlab = 'Shell content (%)')
# axis(side = 1, labels = c(0,5,10,15,20,50), at = c(0,5,10,15,20,50))

m = lm(log(meanMigrationRate) ~ shellContentLabel)
summary(m)
a = m$coefficients[1]
b = m$coefficients[2]
xv = seq(min(shellContentLabel), max(shellContentLabel), length.out = 1000)
yv = exp(a + b*xv)
lines(yv ~ xv, lty = 2, col = 'grey', lwd = 2)
text(x = 25, y = 0.95, expression('(F'['1,4']*'= 295.2, R'^2*'= 0.983, n = 6, p < 0.0001)'))
text(x = 25, y = 0.055, expression('Migration rate = 0.8 * e'^' -0.05 * Shell content (%)'))
dev.off()

# -------------------------------
# Plot 3 - Histograms (Bead load transport)

index = 1:7#c(1,5,2,3,4,6,7)
yv = d$bedloadTransport.cm2_min
yv[] = NA
xv = d$experiment

tiff(filename = 'bedLoadTransport_historgram.tif', width = 15,height = 15, units = 'cm', res = 300)
par(mar = c(5,5,4,4))
plot(yv ~ xv, log = 'x', ylim = c(0.00001,10), horizontal = T,
     yaxt = 'n', xaxt = 'n', 
     xlab = 'Sediment shell content (%)', ylab = expression('Bed load transport (cm'^2*' min'^-1*')'))
axis(side = 1, at = 10^seq(-10,10,1), labels = 10^seq(-10,10,1))
axis(side = 2, at = 1:n_experiments, labels = shellContentLabel, tick = F)
meanMigrationRate = rep(NA, times = n_experiments)
for(i in 1:n_experiments){
  
  filter = d$experiment == levels(d$experiment)[i] & d$photoNumber > 300
  breaks = seq(-20,100,0.04)
  y = hist(log(abs(d$bedloadTransport.cm2_min[filter])), breaks = breaks, plot = F)$density
  x = hist(log(abs(d$bedloadTransport.cm2_min[filter])), breaks = breaks, plot = F)$mids
  
  # rect(xright = y + i, xleft = i, ybottom = exp(x) * 0.95, ytop = exp(x) * 1.05, col = alpha(col[i], 0.7), lty = 0)
  # rect(ytop = y + (n_experiments - i + 0.8), ybottom = (n_experiments - i + 0.8), xright = exp(x) * 0.95, xleft = exp(x) * 1.05, col = alpha(col[i], 0.7), lty = 0)
  rect(ytop = y + index[i] - 0.37, ybottom = index[i] - 0.37, xright = exp(x - diff(breaks)/2), xleft = exp(x + diff(breaks)/2), col = alpha(col[index[i]], 0.7), lty = 0)
  
  meanMigrationRate[i] = mean(d$bedloadTransport.cm2_min[filter])
  lines(y = c(index[i]+0.05 - 0.4,index[i] + 0.8 - 0.4), x = c(meanMigrationRate[i],meanMigrationRate[i]), col = alpha(col[index[i]], 1), lwd = 3)
}
dev.off()

# Regression on migration rate against shell content
tiff(filename = 'bedLoadTransport_regression.tif', width = 15,height = 15, units = 'cm', res = 300)
par(mar = c(5,5,4,4))
plot(meanMigrationRate ~ shellContentLabel, 
     #ylim = c(5,20), xlim = c(-5,25),
     log = 'y', pch = 21, bg = col, #xaxt = 'n',
     ylab = expression('Bed load transport (cm'^2*' min'^-1*')'), xlab = 'Shell content (%)')
# axis(side = 1, labels = c(0,5,10,15,20,50), at = c(0,5,10,15,20,50))

m = lm(log(meanMigrationRate) ~ shellContentLabel)
summary(m)
a = m$coefficients[1]
b = m$coefficients[2]
xv = seq(min(shellContentLabel), max(shellContentLabel), length.out = 1000)
yv = exp(a + b*xv)
lines(yv ~ xv, lty = 2, col = 'grey', lwd = 2)
text(x = 25, y = 0.9, expression('(F'['1,4']*'= 295.2, R'^2*'= 0.936, n = 6, p < 0.0001)'))
text(x = 25, y = 0.01, expression('Bed load transport = 0.92 * e'^' -0.09 * Shell content (%)'))
dev.off()


# -------------------------------
# Ripple asymmetry

index = 1:7#c(1,5,2,3,4,6,7)
yv = d$asymmetry_t0.prop
yv[] = NA
xv = d$experiment

tiff(filename = 'rippleAsymmetry_historgram.tif', width = 15,height = 15, units = 'cm', res = 300)
par(mar = c(5,5,4,4))
plot(yv ~ xv, log = '', ylim = c(0,1), horizontal = T,
     yaxt = 'n', xaxt = 'n', 
     xlab = 'Sediment shell content (%)', ylab = 'Ripple asymmetry (proportion)')
axis(side = 1, at = seq(0,1,0.2), labels = seq(0,1,0.2))
axis(side = 2, at = 1:n_experiments, labels = shellContentLabel, tick = F)
meanMigrationRate = rep(NA, times = n_experiments)
for(i in 1:n_experiments){
  
  filter = d$experiment == levels(d$experiment)[i] & d$photoNumber > 300
  breaks = seq(0,1,0.008)
  y = hist(abs(d$asymmetry_t0.prop[filter]), breaks = breaks, plot = F)$density/7
  x = hist(abs(d$asymmetry_t0.prop[filter]), breaks = breaks, plot = F)$mids
  
  # rect(xright = y + i, xleft = i, ybottom = exp(x) * 0.95, ytop = exp(x) * 1.05, col = alpha(col[i], 0.7), lty = 0)
  # rect(ytop = y + (n_experiments - i + 0.8), ybottom = (n_experiments - i + 0.8), xright = exp(x) * 0.95, xleft = exp(x) * 1.05, col = alpha(col[i], 0.7), lty = 0)
  rect(ytop = y + index[i] - 0.37, ybottom = index[i] - 0.37, xright = x - diff(breaks)/2, xleft = x + diff(breaks)/2, col = alpha(col[index[i]], 0.7), lty = 0)
  
  meanMigrationRate[i] = mean(d$asymmetry_t0.prop[filter])
  lines(y = c(index[i]+0.05 - 0.4,index[i] + 0.8 - 0.4), x = c(meanMigrationRate[i],meanMigrationRate[i]), col = alpha(col[index[i]], 1), lwd = 3)
}
dev.off()

# Regression on migration rate against shell content
tiff(filename = 'rippleAsymmetry_regression.tif', width = 15,height = 15, units = 'cm', res = 300)
par(mar = c(5,5,4,4))
plot(meanMigrationRate ~ shellContentLabel, 
     ylim = c(0,0.5),
     log = '', pch = 21, bg = col, #xaxt = 'n',
     ylab = 'Ripple asymmetry (proportion)', xlab = 'Shell content (%)')
# axis(side = 1, labels = c(0,5,10,15,20,50), at = c(0,5,10,15,20,50))

m = lm(meanMigrationRate ~ shellContentLabel)
summary(m)
a = m$coefficients[1]
b = m$coefficients[2]
xv = seq(min(shellContentLabel), max(shellContentLabel), length.out = 1000)
yv = a + b*xv
lines(yv ~ xv, lty = 2, col = 'grey', lwd = 2)
text(x = 25, y = 0.49, expression('(F'['1,4']*'= 8.6, R'^2*'= 0.60, n = 6, p = 0.042)'))
text(x = 25, y = 0.01, expression('Ripple asymmetry = 0.19 + 0.0026 * Shell content (%)'))
dev.off()
# -------------------------
# Ripple length

index = 1:n_experiments
yv = d$rippleLength_t0.cm
yv[] = NA
xv = d$experiment

tiff(filename = 'rippleLength_histograms.tif', width = 15, height = 15, units = 'cm', res = 300)
par(mar = c(5,5,4,4))
plot(yv ~ xv, log = 'x', ylim = c(0.5,50), horizontal = T,
     yaxt = 'n', xaxt = 'n', 
     xlab = 'Sediment shell content (%)',
     ylab = 'Ripple Length (cm)')
#ylab = expression('Ripple Heigt (cm'^2*')'))
axis(side = 1, at = c(0.1,0.5,1,5,10,50), labels = c(0.1,0.5,1,5,10,50))
axis(side = 2, at = 1:n_experiments, labels = shellContentLabel, tick = F)
mean = sd = se = rep(NA, times = n_experiments)
for(i in 1:n_experiments){
  
  filter = d$experiment == levels(d$experiment)[i] & d$photoNumber > 300
  breaks = seq(-20,10,0.02)
  r = runif(n = length(d$rippleLength_t0.cm), min = -0.1, max = 0.1)
  y = hist(log(d$rippleLength_t0.cm + r)[filter], breaks = breaks, plot = F)$density*0.4
  x = hist(log(d$rippleLength_t0.cm + r)[filter], breaks = breaks, plot = F)$mids
  
  rect(ytop = y + index[i] - 0.37, ybottom = index[i] - 0.37, xright = exp(x - diff(breaks)/2), xleft = exp(x + diff(breaks)/2), col = alpha(col[index[i]], 0.7), lty = 0)
  
  mean[i] = mean(d$rippleLength_t0.cm[filter])
  sd[i] = sd(d$rippleLength_t0.cm[filter])
  se[i] = sd[i]/sqrt(length(d$rippleLength_t0.cm[filter]))
  
  lines(y = c(index[i]+0.05 - 0.4,index[i] + 0.8 - 0.4), x = c(mean[i],mean[i]), col = alpha(col[index[i]], 1), lwd = 3)
}
setwd('SET_TO_CORRECT_DIRECTORY_PATH')
dev.off()

print(paste(round(mean[1],2),'', round(se[1],4)))
print(paste(round(mean[6],2),'', round(se[6],4)))

# Plot 1 - Regression
tiff(filename = 'rippleLength_regression.tif', width = 15, height = 15, units = 'cm', res = 300)
par(mar = c(5,5,4,4))
plot(mean ~ shellContentLabel, log = 'y', pch = 21, bg = col, #xaxt = 'n',
     ylim = c(5,20),
     ylab = 'Ripple Length (cm)', xlab = 'Shell content (%)')
m = lm(log(mean) ~ shellContentLabel)
summary(m)
a = m$coefficients[1]
b = m$coefficients[2]
xv = seq(min(shellContentLabel), max(shellContentLabel), length.out = 1000)
yv = exp(a + b*xv)
lines(yv ~ xv, lty = 2, col = 'grey', lwd = 2)
text(x = 25, y = 19, expression('(F'['1,4']*'= 7.8, R'^2*'= 0.577, n = 6, p = 0.049)'))
text(x = 25, y = 5.2, expression('Ripple Length = 14 * e'^' -0.015 * Shell content (%)'))
# arrows(x0 = shellContentLabel, x1 = shellContentLabel, 
#        y0 = mean + se, y1 = mean - se, 
#        code = 3, angle = 90, length = 0.05)
setwd('SET_TO_CORRECT_DIRECTORY_PATH')
dev.off()
